@@ -1,23 +1,21 @@
-# @(#)Ident: Exception.pm 2013-04-29 17:22 pjf ;
+# @(#)Ident: Exception.pm 2013-04-30 21:44 pjf ;
 
 package Class::Usul::Exception;
 
-# Package namespace::autoclean does not play nice with overload
-use namespace::clean -except => 'meta';
-use version; our $VERSION = qv( sprintf '0.16.%d', q$Rev: 290 $ =~ /\d+/gmx );
+use namespace::autoclean;
+use version; our $VERSION = qv( sprintf '0.17.%d', q$Rev: 6 $ =~ /\d+/gmx );
 
 use Moose;
-use MooseX::Types::Common::String  qw(SimpleStr);
 use MooseX::Types::Common::Numeric qw(PositiveInt);
-use MooseX::Types::Moose           qw(Int);
+use MooseX::Types::Moose           qw(Int Str);
 
-extends q(File::DataClass::Exception);
+extends q(File::DataClass::Exception::Simple);
 
 File::DataClass::Exception->ignore_class( 'Class::Usul::IPC' );
 
 has '+class' => default => __PACKAGE__;
 
-has 'out'    => is => 'ro', isa => SimpleStr, default => q();
+has 'out'    => is => 'ro', isa => Str, default => q();
 
 has 'rv'     => is => 'ro', isa => Int, default => 1;
 
@@ -37,7 +35,7 @@ Class::Usul::Exception - Exception handling
 
 =head1 Version
 
-This documents version v0.16.$Rev: 290 $ of L<Class::Usul::Exception>
+This documents version v0.17.$Rev: 6 $ of L<Class::Usul::Exception>
 
 =head1 Synopsis
 
